# geeda
Pronounced ghee-dah or jee-dee-aye \
Gee.D.A, GEneral EDA: General EDA (Exploratory Data Analysis) Framework for Pandas DataFrames

## Where to get it
The source code is currently hosted on GitHub at:
https://github.com/jjz17/geeda

Binary installers for the latest released version are available at the [Python
Package Index (PyPI)](https://pypi.org/project/geeda/).

```bash
# PyPI
pip install geeda
```

## EDA Workflow using Geeda
1. Create the `Geeda()` object by passing in the dataframe you wish to explore/analyze
2. Call the `apply()` function with the desired arguments (EDA functions that you wish to apply)
3. Enjoy an organized and simple output of the EDA results


# Technologies Used
* Python3
* Poetry (dependency management, publishing library)
* Docker (containerization of services and tests)
* Git/GitHub (version control, CI/CD)
* Pre-commit (hooks for improved code quality)
* Black (code formatting)
